@@ -972,8 +972,8 @@ fn test_fold_get_elem2_1() {
     fold("x = 'string'[5]", "x = \"g\"");
     fold("x = 'string'[0]", "x = \"s\"");
     fold("x = 's'[0]", "x = \"s\"");
-    fold("x = '\\uD83D\\uDCA9'[0]", "x = \"\\ud83d\"");
-    fold("x = '\\uD83D\\uDCA9'[1]", "x = \"\\udca9\"");
+    fold("x = '\\uD83D\\uDCA9'[0]", "x = \"\\uD83D\"");
+    fold("x = '\\uD83D\\uDCA9'[1]", "x = \"\\uDCA9\"");
 }
 
 #[test]
